pyxmpp.jabber.clientstream

Package pyxmpp :: Package jabber :: Module clientstream |
[hide private]

# Module clientstream

source code

XMPP stream support with fallback to legacy non-SASL Jabber authentication.

Normative reference:
  - JEP 78

Classes | [hide private]
| LegacyClientStream Handles Jabber (both XMPP and legacy protocol) client connection stream.

Variables | [hide private]
| __revision__ = ``'``$Id: clientstream.py 703 2010-04-03 17:45:43Z` `...``
| __package__ = ``'``pyxmpp.jabber``'``

Imports: hashlib, logging, Iq, to_utf8, from_utf8, JID, ClientStream, Register, ClientStreamError, LegacyAuthenticationError, RegistrationError

Variables Details | [hide private]

  ### __revision__ Value:
      '$Id: clientstream.py 703 2010-04-03 17:45:43Z jajcus $'